import { h } from 'preact';
import { Clue } from './clue';
import { Row, RowState } from './Row';
import { gameName } from "./util";

export function About() {
    return (
        <div className="App-about">
            <p>
                <i>{gameName}</i> is a spin on the popular word game{" "}
                <a href="https://www.powerlanguage.co.uk/wordle/">
                    <i>Wordle</i>
                </a>{" "}
                by <a href="https://twitter.com/powerlanguish">powerlanguage</a>,
                built on <a href="https://twitter.com/chordbug">chordbug</a>'s{" "}
                <a href="https://github.com/lynn/hello-wordl"><i>hello wordl</i></a> and
                inspired by <a href="https://qntm.org/">qntm</a>'s{" "}
                <a href="https://qntm.org/files/absurdle/absurdle.html"><i>Absurdle</i></a>.
                You start with a prepopulated table of guesses and must find a way to{" "}
                <i>guarantee</i> a win in exactly 2 guesses.
            </p>
            <p>
                The feedback you get on your guesses is <i>adversarial:</i> the game
                changes the secret word as you play. Think about what words it could be,
                then use your first guess to gather as much information as possible.{" "}
                <i>(Hint: hard mode is turned off!)</i>
                <br />
                <br />
                Like Wordle &amp; hello wordl, the game has two separate word lists: a
                "secret list" containing only reasonably common words, and a larger list of
                words you're allowed to guess. The game will let you know when you've typed
                a word that doesn't appear in the secret list; you can still guess it if you
                want, but it can't be the secret word, so try something else if you're on your
                second guess!
                <br />
                <br />
                There's a new puzzle every day, starting at 6 AM in all timezones.
                Each puzzle tells you how many "paths to a win" there are, meaning how many
                pairs of words you can guess to win (<i>not</i> how many words can be the
                secret word). This figure only counts "common" words; you will never be
                forced to guess an uncommon word to win!
            </p>
            <hr />
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={true}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "b" },
                    { clue: Clue.Absent, letter: "a" },
                    { clue: Clue.Elsewhere, letter: "t" },
                    { clue: Clue.Absent, letter: "c" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={true}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "y" },
                    { clue: Clue.Correct, letter: "o" },
                    { clue: Clue.Absent, letter: "u" },
                    { clue: Clue.Correct, letter: "t" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={true}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "t" },
                    { clue: Clue.Correct, letter: "o" },
                    { clue: Clue.Absent, letter: "o" },
                    { clue: Clue.Correct, letter: "t" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <p>
                We know the word has an <b class="green-bg">O</b> in the second position
                and ends with <b class="green-bg">TH</b>. What words could it be?
            </p>
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={false}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "n" },
                    { clue: Clue.Correct, letter: "o" },
                    { clue: Clue.Correct, letter: "r" },
                    { clue: Clue.Correct, letter: "t" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={false}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "f" },
                    { clue: Clue.Correct, letter: "o" },
                    { clue: Clue.Correct, letter: "r" },
                    { clue: Clue.Correct, letter: "t" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <p style={{ fontSize: "80%" }}>Not quite! The answer could've been <strong>WORTH</strong>.</p>
            <p>Looks like we didn't cover all our bases. Let's see if we can account for that <b>W</b>:</p>
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={false}
                cluedLetters={[
                    { clue: Clue.Absent, letter: "s" },
                    { clue: Clue.Absent, letter: "w" },
                    { clue: Clue.Elsewhere, letter: "o" },
                    { clue: Clue.Elsewhere, letter: "r" },
                    { clue: Clue.Absent, letter: "n" },
                ]}
            />
            <Row
                rowState={RowState.LockedIn}
                wordLength={5}
                isPartOfPuzzle={false}
                cluedLetters={[
                    { clue: Clue.Correct, letter: "f" },
                    { clue: Clue.Correct, letter: "o" },
                    { clue: Clue.Correct, letter: "r" },
                    { clue: Clue.Correct, letter: "t" },
                    { clue: Clue.Correct, letter: "h" },
                ]}
            />
            <p style={{ fontSize: "80%" }}>You won in 2 tries! Great job.</p>
            <p>There! The game had no choice but to narrow it down to one word.</p>
            <hr />
            <p>
                Like hello wordl, this game will be free and ad-free for as long as
                it's online.
                <br />
                <a href="https://meow.garden/contact-me">Contact Ash</a> if you have
                any questions.
            </p>
        </div>
    );
}
