import { useState } from "preact/hooks";

export function useLocalStorage<T>(
    key: string,
    initial: T
): [T, (value: T | ((t: T) => T)) => void] {
    const [current, setCurrent] = useState<T>(() => {
        try {
            const item = window.localStorage.getItem(key);
            return item ? JSON.parse(item) : initial;
        } catch (e) {
            return initial;
        }
    });
    const setSetting = (value: T | ((t: T) => T)) => {
        try {
            const v = value instanceof Function ? value(current) : value;
            setCurrent(v);
            window.localStorage.setItem(key, JSON.stringify(v));
        } catch (e) { }
    };
    return [current, setSetting];
}